@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.45 2002/10/25 22:12:26 kevinv Exp $
+ $Id: battstat_applet.c,v 1.50 2003/06/04 00:39:39 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,8 @@
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
+#include <egg-screen-help.h>
+
 /*#include <status-docklet.h>*/
 
 #include "battstat.h"
@@ -666,7 +668,10 @@ destroy_applet (GtkWidget *widget, gpointer data)
    ProgressData *pdata = data;
    
    if (DEBUG) g_print("destroy_applet()\n");
-   
+
+   if (pdata->prop_win)
+	gtk_widget_destroy (GTK_WIDGET (pdata->prop_win));
+
    gtk_timeout_remove (pdata->pixtimer);
    pdata->pixtimer = 0;
    pdata->applet = NULL;
@@ -736,12 +741,18 @@ help_cb (BonoboUIComponent *uic,
 	 ProgressData      *battstat,
 	 const char        *verb)
 {
-  /* FIXME: use (egg|gnome)_screen_help_display
-   GnomeHelpMenuEntry help_entry = {
-      "battstat_applet", "index.html"
-   };
-   gnome_help_display (NULL, &help_entry);
-  */
+    GError *error = NULL;
+
+    egg_help_display_on_screen (
+		"battstat", NULL,
+		gtk_widget_get_screen (battstat->applet),
+		&error);
+
+    if (error) { /* FIXME: the user needs to see this */
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
 }
 
 void
@@ -841,7 +852,7 @@ about_cb (BonoboUIComponent *uic,
 				_("Battery Charge Monitor"), 
 				VERSION,
 				_("(C) 2000 The Gnulix Society, (C) 2002 Free Software Foundation"),
-				_("This utility show the status of your laptop battery."),
+				_("This utility shows the status of your laptop battery."),
 				authors,
 				documenters,
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -1457,6 +1468,7 @@ battstat_applet_fill (PanelApplet *applet)
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/battstat.png");
   
   panel_applet_add_preferences (applet, "/schemas/apps/battstat-applet/prefs", NULL);
+  panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
   apm_readinfo (applet);
   
@@ -1522,7 +1534,7 @@ battstat_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_BattstatApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "Battstat",
+                             "battstat",
                              "0",
                              battstat_applet_factory,
                              NULL)
