@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.54 2003/03/26 01:34:18 kevinv Exp $ */
+/* $Id: gweather-pref.c,v 1.61 2003/06/06 15:33:15 dcransto Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -34,6 +34,35 @@ static void gweather_pref_set_accessibility (GWeatherApplet *gw_applet);
 static void help_cb (GtkDialog *dialog);
 
 
+GtkWidget *
+hig_category_new (GtkWidget *parent, gchar *title, gboolean expand, gboolean fill)
+{
+	GtkWidget *vbox, *vbox2, *hbox;
+	GtkWidget *label;
+	gchar *tmp;
+	
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (parent), vbox, expand, fill, 0);
+
+	tmp = g_strdup_printf ("<b>%s</b>", _(title));
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_markup (GTK_LABEL (label), tmp);
+	g_free (tmp);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
+
+	return vbox2;
+}
+
 /* sets up ATK Relation between the widgets */
 
 void
@@ -155,7 +184,7 @@ show_labels_toggled (GtkToggleButton *button, gpointer data)
     gw_applet->gweather_pref.show_labels= toggled;
     panel_applet_gconf_set_bool(gw_applet->applet, "show_labels", toggled, NULL);
 
-   for (i=0; i<=gw_applet->gweather_info->numforecasts; i++) {
+   for (i=0; i<=gw_applet->gweather_info->numforecasts-1; i++) {
 	if (toggled)
 		gtk_widget_show (gw_applet->labels[i]);
 	else
@@ -231,7 +260,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     GtkWidget *vbox, *vbox2, *vbox3;
     GtkWidget *spin, *label;
     GtkWidget *scrolled, *check;
-    GtkSizeGroup *size;
+    GtkWidget *table;
     gchar *tmp;
     
     gw_applet->pref = gtk_dialog_new_with_buttons (_("Weather Preferences"), NULL,
@@ -240,6 +269,8 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 				      		   GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 				      		   NULL);
     gtk_dialog_set_default_response (GTK_DIALOG (gw_applet->pref), GTK_RESPONSE_CLOSE);
+    gtk_dialog_set_has_separator (GTK_DIALOG (gw_applet->pref), FALSE);
+    gtk_container_set_border_width (GTK_CONTAINER (gw_applet->pref), 5);
     gtk_window_set_default_size(GTK_WINDOW (gw_applet->pref), 400,400);
     gtk_window_set_policy (GTK_WINDOW (gw_applet->pref), TRUE, TRUE, FALSE);
     gtk_window_set_screen (GTK_WINDOW (gw_applet->pref),
@@ -251,9 +282,9 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 
     pref_notebook = gtk_notebook_new ();
     gtk_widget_show (pref_notebook);
+    gtk_container_set_border_width (GTK_CONTAINER (pref_notebook), 5);
     gtk_box_pack_start (GTK_BOX (pref_vbox), pref_notebook, TRUE, TRUE, 0);
 
-    size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
    
   /*
@@ -266,33 +297,20 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 							 pref_basic_note_lbl);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
-    frame = gtk_frame_new (NULL);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);	
-    label = gtk_label_new (NULL);
-    tmp = g_strdup_printf ("<b>%s</b>", _("Update"));
-    gtk_label_set_markup (GTK_LABEL (label), tmp);
-    g_free (tmp);
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-
-    vbox2 = gtk_vbox_new (FALSE, 6);
-    gtk_container_add (GTK_CONTAINER (frame), vbox2);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox2), 12);
-
-    hbox = gtk_hbox_new (FALSE, 6);
+    vbox2 = hig_category_new (vbox, _("Update"), FALSE, FALSE);
+    hbox = gtk_hbox_new (FALSE, 12);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
 
-    gw_applet->pref_basic_update_btn = gtk_check_button_new_with_mnemonic (_("_Automatically update every"));
+    gw_applet->pref_basic_update_btn = gtk_check_button_new_with_mnemonic (_("_Automatically update every:"));
     gtk_widget_show (gw_applet->pref_basic_update_btn);
-    gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_basic_update_btn, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_basic_update_btn, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (gw_applet->pref_basic_update_btn), "toggled",
     		      G_CALLBACK (auto_update_toggled), gw_applet);
-
-    hbox2 = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_end (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
-    gtk_size_group_add_widget (size, hbox2);
     
-    pref_basic_update_spin_adj = gtk_adjustment_new (30, 1, 60, 5, 25, 1);
+    hbox2 = gtk_hbox_new (FALSE, 6);
+    gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
+
+    pref_basic_update_spin_adj = gtk_adjustment_new (30, 30, 3600, 5, 25, 1);
     gw_applet->pref_basic_update_spin = gtk_spin_button_new (GTK_ADJUSTMENT (pref_basic_update_spin_adj), 1, 0);
     gtk_widget_show (gw_applet->pref_basic_update_spin);
     gtk_box_pack_start (GTK_BOX (hbox2), gw_applet->pref_basic_update_spin,
@@ -309,25 +327,12 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_update_btn), 
     				 gw_applet->gweather_pref.update_enabled);
 
-    pref_basic_update_sec_lbl = gtk_label_new (_("minute(s)"));
+    pref_basic_update_sec_lbl = gtk_label_new (_("minutes"));
     gtk_widget_show (pref_basic_update_sec_lbl);
     gtk_box_pack_start (GTK_BOX (hbox2), pref_basic_update_sec_lbl, FALSE, FALSE, 0);
 
-    frame = gtk_frame_new (NULL);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);	
-    label = gtk_label_new (NULL);
-    tmp = g_strdup_printf ("<b>%s</b>", _("Display"));
-    gtk_label_set_markup (GTK_LABEL (label), tmp);
-    g_free (tmp);
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    vbox2 = hig_category_new (vbox, _("Display"), FALSE, FALSE);
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
-    gtk_container_add (GTK_CONTAINER (frame), vbox2);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox2), 12);
-
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
     gw_applet->pref_basic_metric_btn = gtk_check_button_new_with_mnemonic (_("Use _metric system units"));
     gtk_box_pack_start (GTK_BOX (vbox2), gw_applet->pref_basic_metric_btn, FALSE, FALSE, 0);
     gtk_widget_show (gw_applet->pref_basic_metric_btn);
@@ -336,9 +341,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_metric_btn), 
     				 gw_applet->gweather_pref.use_metric);
 
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
-    check = gtk_check_button_new_with_mnemonic (_("Display daily average temperatures"));
+    check = gtk_check_button_new_with_mnemonic (_("Display _temperatures"));
     gtk_box_pack_start (GTK_BOX (vbox2), check, FALSE, FALSE, 0);
     gtk_widget_show (gw_applet->pref_basic_metric_btn);
     g_signal_connect (G_OBJECT (check), "toggled",
@@ -346,19 +349,24 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), 
     				 gw_applet->gweather_pref.show_labels);
     
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (FALSE, 12);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new_with_mnemonic (_("Number of _forecast days to display:"));
+    label = gtk_label_new_with_mnemonic (_("Number of _days to display:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     
-    spin = gtk_spin_button_new_with_range (0, 5, 1);
+    hbox2 = gtk_hbox_new (FALSE, 6);
+    gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
+    
+    spin = gtk_spin_button_new_with_range (1, 6, 1);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin), gw_applet->gweather_info->numforecasts);
     g_signal_connect (G_OBJECT (spin), "value_changed",
     		      G_CALLBACK (num_forecasts_changed), gw_applet);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin);
-    gtk_box_pack_end	(GTK_BOX (hbox), spin, FALSE, FALSE, 0);
-    gtk_size_group_add_widget (size, spin);
+    gtk_box_pack_start (GTK_BOX (hbox2), spin, FALSE, FALSE, 0);
+    
+    label = gtk_label_new_with_mnemonic (_("days"));
+    gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, TRUE, 0);
 
   /*
    * Location page.
@@ -369,50 +377,48 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 							 label);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
-    frame = gtk_frame_new (NULL);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);	
-    label = gtk_label_new (NULL);
-    tmp = g_strdup_printf ("<b>%s</b>", _("Location"));
-    gtk_label_set_markup (GTK_LABEL (label), tmp);
-    g_free (tmp);
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    frame = hig_category_new (vbox, _("Location"), TRUE, TRUE);
 
-    vbox2 = gtk_vbox_new (FALSE, 6);
-    gtk_container_add (GTK_CONTAINER (frame), vbox2);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox2), 12);
-
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
+    hbox = gtk_hbox_new (FALSE, 12);
+    gtk_box_pack_start (GTK_BOX (frame), hbox, FALSE, FALSE, 0);
     label = gtk_label_new (_("Current city:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gw_applet->pref_location_city_label = gtk_label_new (gw_applet->gweather_pref.city);
     gtk_box_pack_start (GTK_BOX (hbox), gw_applet->pref_location_city_label, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (TRUE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
-
-    vbox3 = gtk_vbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (hbox), vbox3, TRUE, TRUE, 0); 
-    hbox2 = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox3), hbox2, FALSE, FALSE, 0); 
+    table = gtk_table_new (2, 2, FALSE);
+    gtk_widget_show (table);
+    gtk_box_pack_start (GTK_BOX (frame), table, TRUE, TRUE, 0);
+    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+ 
     label = gtk_label_new_with_mnemonic (_("Available c_ountries:"));
-    gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    
     scrolled = create_countries_widget (gw_applet);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), gw_applet->country_tree);
-    scrolled = create_countries_widget (gw_applet);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), gw_applet->country_tree);
-    gtk_box_pack_start (GTK_BOX (vbox3), scrolled, TRUE, TRUE, 0);
+    gtk_widget_show (scrolled);
+    gtk_table_attach (GTK_TABLE (table), scrolled, 0, 1, 1, 2,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 
-    vbox3 = gtk_vbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (hbox), vbox3, TRUE, TRUE, 0);
-    hbox2 = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox3), hbox2, FALSE, FALSE, 0); 
     label = gtk_label_new_with_mnemonic (_("Available c_ities:"));    
-    gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);    
+    
     scrolled = create_cities_widget (gw_applet);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), gw_applet->city_tree);
-    gtk_box_pack_start (GTK_BOX (vbox3), scrolled, TRUE, TRUE, 0);
+    gtk_widget_show (scrolled);
+    gtk_table_attach (GTK_TABLE (table), scrolled, 1, 2, 1, 2,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 
     g_signal_connect (G_OBJECT (gw_applet->pref), "response",
     		      G_CALLBACK (response_cb), gw_applet);
@@ -439,7 +445,7 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
 	g_error_free (error);
 	error = NULL;
     }
-    gw_applet->gweather_pref.update_interval = MAX (gw_applet->gweather_pref.update_interval, 1000);
+    gw_applet->gweather_pref.update_interval = MAX (gw_applet->gweather_pref.update_interval, 1800);
     gw_applet->gweather_pref.update_enabled =
     	panel_applet_gconf_get_bool(gw_applet->applet, "auto_update", NULL);
     gw_applet->gweather_pref.use_metric = 
@@ -448,11 +454,11 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
     gw_applet->gweather_info->numforecasts = panel_applet_gconf_get_int (gw_applet->applet,
     								    "num_forecasts",
     								    NULL);
-    gw_applet->gweather_info->numforecasts = CLAMP (gw_applet->gweather_info->numforecasts, 0, 5);
+    gw_applet->gweather_info->numforecasts = CLAMP (gw_applet->gweather_info->numforecasts, 1, 6);
     gw_applet->gweather_pref.url = NULL;
     gw_applet->gweather_pref.url = panel_applet_gconf_get_string(gw_applet->applet, "url", NULL);
     gw_applet->gweather_pref.city = panel_applet_gconf_get_string(gw_applet->applet, "city", NULL);
-    g_print ("city %s name \n", gw_applet->gweather_pref.url);
+    
     if (!gw_applet->gweather_pref.url || (strlen (gw_applet->gweather_pref.url)==0)) {
 	gw_applet->gweather_pref.url=g_strdup ("http://weather.interceptvector.com/weather.xml?id=VVNQQTEyOTA%3D");
 	gw_applet->gweather_pref.city = g_strdup ("Pittsburgh");
